PBufState

Enum PBufState 

pub enum PBufState {
    Open = 0,
    Push = 1,
    Closing = 3,
    Closed = 2,
    Aborting = 5,
    Aborted = 4,
}
End-of-file and “push” state of the buffer

Variants



Open = 0

End-of-file has not been reached yet. More data may follow.



Push = 1

End-of-file has not been reached yet. More data may follow. Producer has suggested that current data be flushed.



Closing = 3

The producer has reported a successful end-of-file. Any data left in the buffer is the final data of the stream. The consumer has not yet processed the EOF.



Closed = 2

Successful end-of-file has been reported by the producer and processed by the consumer.



Aborting = 5

The producer has reported end-of-file due to some error condition. The data in the stream might be in an inconsistent or incomplete state (e.g. a partial record, protocol not terminated normally, etc). The consumer has not yet processed the EOF.



Aborted = 4

Abort end-of-file has been reported by the producer and processed by the consumer.